@@ -120,7 +120,7 @@ impl Default for NSTDEventData {
 /// Returns: `NSTDEventLoop event_loop` - The event loop.
 #[inline]
 #[cfg_attr(feature = "clib", no_mangle)]
-pub unsafe extern "C" fn nstd_std_events_event_loop_new() -> NSTDEventLoop {
+pub unsafe extern "C" fn nstd_events_event_loop_new() -> NSTDEventLoop {
     #[cfg(not(any(target_os = "windows", target_os = "linux")))]
     return Box::into_raw(Box::new(EventLoop::new()));
     #[cfg(any(target_os = "windows", target_os = "linux"))]
@@ -137,7 +137,7 @@ pub unsafe extern "C" fn nstd_std_events_event_loop_new() -> NSTDEventLoop {
 ///     `NSTDEventLoop *event_loop` - The event loop to run.
 ///     `NSTDEventLoopControlFlow(*callback)(NSTDEventData *)` - Called once per event.
 #[cfg_attr(feature = "clib", no_mangle)]
-pub unsafe extern "C" fn nstd_std_events_event_loop_run(
+pub unsafe extern "C" fn nstd_events_event_loop_run(
     event_loop: *mut NSTDEventLoop,
     callback: extern "C" fn(*mut NSTDEventData) -> NSTDEventLoopControlFlow,
     should_return: c_int,
@@ -186,10 +186,10 @@ pub unsafe extern "C" fn nstd_std_events_event_loop_run(
                         }
                         WindowEvent::ModifiersChanged(mods) => {
                             event_data.mod_keys = 0
-                                | NSTD_STD_INPUT_KEY_SHIFT_BIT * mods.shift() as u8
-                                | NSTD_STD_INPUT_KEY_CTRL_BIT * mods.ctrl() as u8
-                                | NSTD_STD_INPUT_KEY_ALT_BIT * mods.alt() as u8
-                                | NSTD_STD_INPUT_KEY_LOGO_BIT * mods.logo() as u8;
+                                | NSTD_INPUT_KEY_SHIFT_BIT * mods.shift() as u8
+                                | NSTD_INPUT_KEY_CTRL_BIT * mods.ctrl() as u8
+                                | NSTD_INPUT_KEY_ALT_BIT * mods.alt() as u8
+                                | NSTD_INPUT_KEY_LOGO_BIT * mods.logo() as u8;
                             NSTD_EVENT_WINDOW_MOD_KEY
                         }
                         WindowEvent::CursorMoved { position, .. } => {
@@ -287,7 +287,7 @@ pub unsafe extern "C" fn nstd_std_events_event_loop_run(
 ///     `NSTDEventLoop *event_loop` - The event loop to free.
 #[inline]
 #[cfg_attr(feature = "clib", no_mangle)]
-pub unsafe extern "C" fn nstd_std_events_event_loop_free(event_loop: *mut NSTDEventLoop) {
+pub unsafe extern "C" fn nstd_events_event_loop_free(event_loop: *mut NSTDEventLoop) {
     Box::from_raw(*event_loop);
     *event_loop = ptr::null_mut();
 }
